==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/StandardDeviationIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StandardDeviationIndicatorStrategy } from "./StandardDeviationIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var StandardDeviationIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StandardDeviationIndicator, _super);
    function StandardDeviationIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StandardDeviationIndicator.prototype.get_ul = function () {
        return new StandardDeviationIndicatorStrategy();
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    StandardDeviationIndicator.prototype.get_uy = function () {
        return StandardDeviationIndicator.$;
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StandardDeviationIndicator.prototype, "u6", {
        get: function () {
            return typeGetValue(this.c(StandardDeviationIndicator.u7));
        },
        set: function (a) {
            this.h(StandardDeviationIndicator.u7, a);
        },
        enumerable: false,
        configurable: true
    });
    StandardDeviationIndicator.prototype.ur = function () {
        return this.u6;
    };
    StandardDeviationIndicator.prototype.u0 = function (a) {
        this.u6 = a;
    };
    StandardDeviationIndicator.$t = markType(StandardDeviationIndicator, 'StandardDeviationIndicator', StrategyBasedIndicator.$);
    StandardDeviationIndicator.u7 = StrategyBasedIndicator.u3(20, StandardDeviationIndicator.$);
    return StandardDeviationIndicator;
}(StrategyBasedIndicator));
export { StandardDeviationIndicator };

==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/StandardDeviationIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StandardDeviationIndicatorStrategy } from "./StandardDeviationIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var StandardDeviationIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StandardDeviationIndicator, _super);
    function StandardDeviationIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StandardDeviationIndicator.prototype.bg = function () {
        return new StandardDeviationIndicator();
    };
    StandardDeviationIndicator.prototype.get_yz = function () {
        return new StandardDeviationIndicatorStrategy();
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    StandardDeviationIndicator.prototype.get_zc = function () {
        return StandardDeviationIndicator.$;
    };
    Object.defineProperty(StandardDeviationIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StandardDeviationIndicator.prototype, "zk", {
        get: function () {
            return typeGetValue(this.c(StandardDeviationIndicator.zl));
        },
        set: function (a) {
            this.h(StandardDeviationIndicator.zl, a);
        },
        enumerable: false,
        configurable: true
    });
    StandardDeviationIndicator.prototype.y5 = function () {
        return this.zk;
    };
    StandardDeviationIndicator.prototype.ze = function (a) {
        this.zk = a;
    };
    StandardDeviationIndicator.$t = markType(StandardDeviationIndicator, 'StandardDeviationIndicator', StrategyBasedIndicator.$);
    StandardDeviationIndicator.zl = StrategyBasedIndicator.zh(20, StandardDeviationIndicator.$);
    return StandardDeviationIndicator;
}(StrategyBasedIndicator));
export { StandardDeviationIndicator };
